# README #

### What is this repository for? ###

* messenger gui client - chat.
* Study project
* Version 1.0 ALFA

### install ###

* on linux:
    * Create virtual environment: python3 -m venv <dir name>
    * cd <"dir name">
    * source bin\activate <"dir name">
    * in console -> pypi_chat

* on windows:
    * pip install virtualenv
    * virtualenv <имя виртуального окружения>
    * <имя виртуального окружения>\Scripts\activate

* pip install pypi_chat

### How do I RUN? ###
* PYTHON 3 !!!
* in console -> pypi_chat_client

* IF YOU DON'T WANT TO CREATE virtual environment (for some reason ;))
    * Just pip install and:
        * on windows: run cmd >> python3 <your python way>/scripts/pypi_chat_client
        * on linux: in console >> pypi_chat_client

### TO DO ###
* LEARN!
* refactoring! refactoring! refactoring! :D
* need security